@@ -45,16 +45,40 @@ pub fn walk_tree(h: &Handle, context: String, entries: &mut Vec<Option<Entry>>)
                                                                  .unwrap_or(String::from("")))),
                                                                      false)),
 
-                    ("h4", "type") =>
+                    ("span", "variant") => {
+                        let entry_name_type = extract_entry_name(&e, Some("invisible"));
+                        let entry_name = entry_name_type.as_ref()
+                                                        .unwrap()
+                                                        .split('(')
+                                                        .nth(0)
+                                                        .unwrap();
                         entries.push(Entry::new(e.clone(),
-                                                "Type",
-                                                extract_entry_name(&e, None).and_then(|s| {
-                                                    Some(s.replace("type ", "::")
-                                                          .replace(" = ", "=")
-                                                          .rsplit('=')
-                                                          .collect())
-                                                }),
-                                                false)),
+                                                "Variant",
+                                                Some(format!("{}::{}", context, entry_name)),
+                                                false))
+                    }
+
+                    ("span", "structfield") => {
+                        let entry_name_type = extract_entry_name(&e, Some("invisible"));
+                        let entry_name = entry_name_type.as_ref()
+                                                        .unwrap()
+                                                        .split(':')
+                                                        .nth(0)
+                                                        .unwrap();
+                        entries.push(Entry::new(e.clone(),
+                                                "Field",
+                                                Some(format!("{}::{}", context, entry_name)),
+                                                false))
+                    }
+
+                    ("h4", "type") => entries.push(Entry::new(e.clone(),
+                                                              "Type",
+                                                              Some(format!("{}::{}",
+                                                             context,
+                                                             extract_entry_name(&e,
+                                                                                Some("type"))
+                                                                 .unwrap())),
+                                                              false)),
 
                     ("section", "content constant") =>
                         entries.push(Entry::new(e.clone(),
